summaryrefslogtreecommitdiff
path: root/contrib/cirrus/upload_release_archive.sh
diff options
context:
space:
mode:
Diffstat (limited to 'contrib/cirrus/upload_release_archive.sh')
-rwxr-xr-xcontrib/cirrus/upload_release_archive.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/contrib/cirrus/upload_release_archive.sh b/contrib/cirrus/upload_release_archive.sh
index 2716c402c..a94a5cc82 100755
--- a/contrib/cirrus/upload_release_archive.sh
+++ b/contrib/cirrus/upload_release_archive.sh
@@ -19,8 +19,8 @@ then
BUCKET="libpod-pr-releases"
elif [[ -n "$CIRRUS_BRANCH" ]]
then
- # Only release non-development tagged commit ranges
- if is_release
+ # Only release binaries for tagged commit ranges, unless working on docs
+ if is_release || [[ $CIRRUS_TASK_NAME =~ "docs" ]]
then
PR_OR_BRANCH="$CIRRUS_BRANCH"
BUCKET="libpod-$CIRRUS_BRANCH-releases"